import React, { useState, useEffect } from 'react';
import './App.css';
import ConfigForm from './components/ConfigForm';
import MealPlanDisplay from './components/MealPlanDisplay';
import ExportTools from './components/ExportTools';
import AIDebugPanel from './components/AIDebugPanel';
import GeminiTest from './components/GeminiTest';
import MealPlanService from './services/MealPlanService';

function App() {
  const [mealPlanConfig, setMealPlanConfig] = useState({
    portions: 6,
    mealsPerInterval: 7,
    shoppingIntervalUnit: 'days', // New setting
    shoppingIntervalQuantity: 7, // New setting
    numberOfIntervals: 1, // New setting
    likedFlavors: ['classic american', 'classic italian', 'asian', 'mexican'],
    dislikedFlavors: [],
    allergies: [],
    specialInstructions: ['Friday is pizza night from Marcos', 'Include one novel dish per week'],
    startDate: new Date(),
    cookingEquipment: ['oven', 'crockpot', 'stove']
  });

  const [generatedPlan, setGeneratedPlan] = useState(null);
  const [isLoading, setIsLoading] = useState(false);
  const [error, setError] = useState(null);
  const [calendarEvents, setCalendarEvents] = useState(null);
  const [isDarkMode, setIsDarkMode] = useState(false); // New state for dark mode

  // Effect to apply dark mode class to body
  useEffect(() => {
    if (isDarkMode) {
      document.body.classList.add('dark-mode');
    } else {
      document.body.classList.remove('dark-mode');
    }
  }, [isDarkMode]);

  const handleConfigUpdate = (newConfig) => {
    setMealPlanConfig(newConfig);
  };

  const generateMealPlan = async () => {
    setIsLoading(true);
    setError(null);

    try {
      // Call our service to generate the meal plan
      const plan = await MealPlanService.generateMealPlan(mealPlanConfig);
      setGeneratedPlan(plan);

      // Generate calendar events
      const events = await MealPlanService.generateCalendarEvents(plan);
      setCalendarEvents(events);
    } catch (err) {
      // Provide more detailed error message if available
      if (err.message && err.message.includes('Gemini API error')) {
        setError(`Failed to generate meal plan: ${err.message}`);
      } else {
        setError('Failed to generate meal plan. Please try again.');
      }
      console.error('Error generating meal plan:', err);
    } finally {
      setIsLoading(false);
    }
  };

  // Function to toggle dark mode
  const toggleDarkMode = () => {
    setIsDarkMode(!isDarkMode);
  };

  return (
    <div className="App">
      <header className="App-header">
        <h1>Meal Planner</h1>
        {/* Dark mode toggle button */}
        <button onClick={toggleDarkMode} className="dark-mode-toggle">
          {isDarkMode ? 'Switch to Light Mode' : 'Switch to Dark Mode'}
        </button>
      </header>

      <GeminiTest />

      <main>
        <ConfigForm
          config={mealPlanConfig}
          onConfigUpdate={handleConfigUpdate}
          onGeneratePlan={generateMealPlan}
          isLoading={isLoading}
        />

        {isLoading && (
          <div className="loading-indicator">
            <p>Generating your meal plan...</p>
            <div className="spinner"></div>
          </div>
        )}

        {error && (
          <div className="error-message">
            <p>{error}</p>
          </div>
        )}

        {generatedPlan && !isLoading && (
          <>
            <MealPlanDisplay plan={generatedPlan} />
            <ExportTools plan={generatedPlan} calendarEvents={calendarEvents} />
            <AIDebugPanel
              aiPrompt={generatedPlan.aiPrompt}
              rawAIResponse={generatedPlan.rawAIResponse}
            />
          </>
        )}
      </main>
    </div>
  );
}

export default App;
