import React, { useState, useEffect } from 'react';
import './ConfigForm.css';
import SavedConfigs from './SavedConfigs';

const ConfigForm = ({ config, onConfigUpdate, onGeneratePlan, isLoading }) => {
  const [localConfig, setLocalConfig] = useState(config);
  const [newLikedFlavor, setNewLikedFlavor] = useState('');
  const [newDislikedFlavor, setNewDislikedFlavor] = useState('');
  const [newAllergy, setNewAllergy] = useState('');
  const [newInstruction, setNewInstruction] = useState('');
  const [newEquipment, setNewEquipment] = useState('');
  
  // Save current config to localStorage whenever it changes
  useEffect(() => {
    // Convert Date to string for localStorage
    const configToSave = {
      ...localConfig,
      startDate: localConfig.startDate.toISOString()
    };
    localStorage.setItem('currentMealPlanConfig', JSON.stringify(configToSave));
  }, [localConfig]);

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setLocalConfig({
      ...localConfig,
      [name]: value
    });
  };

  const handleNumberChange = (e) => {
    const { name, value } = e.target;
    setLocalConfig({
      ...localConfig,
      [name]: parseInt(value, 10) || 0
    });
  };

  const handleDateChange = (e) => {
    setLocalConfig({
      ...localConfig,
      startDate: new Date(e.target.value)
    });
  };

  const addToList = (listName, value, setValue) => {
    if (value.trim()) {
      setLocalConfig({
        ...localConfig,
        [listName]: [...localConfig[listName], value.trim()]
      });
      setValue('');
    }
  };

  const removeFromList = (listName, index) => {
    setLocalConfig({
      ...localConfig,
      [listName]: localConfig[listName].filter((_, i) => i !== index)
    });
  };

  const handleSaveConfig = () => {
    onConfigUpdate(localConfig);
  };
  
  const handleLoadSavedConfig = (savedConfig) => {
    setLocalConfig(savedConfig);
    onConfigUpdate(savedConfig);
  };

  return (
    <div className="config-form">
      <h2>Meal Plan Configuration</h2>
      
      <SavedConfigs onLoadConfig={handleLoadSavedConfig} />
      
      <div className="form-section">
        <h3>Basic Settings</h3>
        <div className="form-group">
          <label htmlFor="portions">Number of Portions:</label>
          <input
            type="number"
            id="portions"
            name="portions"
            value={localConfig.portions}
            onChange={handleNumberChange}
            min="1"
          />
        </div>
        
        <div className="form-group">
          <label htmlFor="mealsPerInterval">Meals per Shopping Interval:</label>
          <input
            type="number"
            id="mealsPerInterval"
            name="mealsPerInterval"
            value={localConfig.mealsPerInterval}
            onChange={handleNumberChange}
            min="1"
          />
        </div>
        
        <div className="form-group">
          <label htmlFor="startDate">Start Date:</label>
          <input
            type="date"
            id="startDate"
            name="startDate"
            value={localConfig.startDate.toISOString().split('T')[0]}
            onChange={handleDateChange}
          />
        </div>

        <div className="form-group">
          <label htmlFor="shoppingIntervalUnit">Shopping Interval Unit:</label>
          <select
            id="shoppingIntervalUnit"
            name="shoppingIntervalUnit"
            value={localConfig.shoppingIntervalUnit || 'days'}
            onChange={handleInputChange}
          >
            <option value="days">Days</option>
            <option value="weeks">Weeks</option>
          </select>
        </div>

        <div className="form-group">
          <label htmlFor="shoppingIntervalQuantity">Shopping Interval Quantity:</label>
          <input
            type="number"
            id="shoppingIntervalQuantity"
            name="shoppingIntervalQuantity"
            value={localConfig.shoppingIntervalQuantity || 1}
            onChange={handleNumberChange}
            min="1"
          />
        </div>

        <div className="form-group">
          <label htmlFor="numberOfIntervals">Number of Intervals to Generate:</label>
          <input
            type="number"
            id="numberOfIntervals"
            name="numberOfIntervals"
            value={localConfig.numberOfIntervals || 1}
            onChange={handleNumberChange}
            min="1"
          />
        </div>
      </div>
      
      <div className="form-section">
        <h3>Preferences</h3>
        
        <div className="form-group">
          <label>Flavors & Styles I Like:</label>
          <div className="list-with-input">
            <input
              type="text"
              value={newLikedFlavor}
              onChange={(e) => setNewLikedFlavor(e.target.value)}
              placeholder="Enter flavor or style"
            />
            <button 
              type="button" 
              onClick={() => addToList('likedFlavors', newLikedFlavor, setNewLikedFlavor)}
            >
              Add
            </button>
          </div>
          <ul className="tag-list">
            {localConfig.likedFlavors.map((flavor, index) => (
              <li key={`like-${index}`} className="tag">
                {flavor}
                <button 
                  type="button" 
                  onClick={() => removeFromList('likedFlavors', index)}
                  className="remove-button"
                >
                  ×
                </button>
              </li>
            ))}
          </ul>
        </div>
        
        <div className="form-group">
          <label>Flavors & Styles I Dislike:</label>
          <div className="list-with-input">
            <input
              type="text"
              value={newDislikedFlavor}
              onChange={(e) => setNewDislikedFlavor(e.target.value)}
              placeholder="Enter flavor or style"
            />
            <button 
              type="button" 
              onClick={() => addToList('dislikedFlavors', newDislikedFlavor, setNewDislikedFlavor)}
            >
              Add
            </button>
          </div>
          <ul className="tag-list">
            {localConfig.dislikedFlavors.map((flavor, index) => (
              <li key={`dislike-${index}`} className="tag">
                {flavor}
                <button 
                  type="button" 
                  onClick={() => removeFromList('dislikedFlavors', index)}
                  className="remove-button"
                >
                  ×
                </button>
              </li>
            ))}
          </ul>
        </div>
        
        <div className="form-group">
          <label>Food Allergies:</label>
          <div className="list-with-input">
            <input
              type="text"
              value={newAllergy}
              onChange={(e) => setNewAllergy(e.target.value)}
              placeholder="Enter allergy"
            />
            <button 
              type="button" 
              onClick={() => addToList('allergies', newAllergy, setNewAllergy)}
            >
              Add
            </button>
          </div>
          <ul className="tag-list">
            {localConfig.allergies.map((allergy, index) => (
              <li key={`allergy-${index}`} className="tag">
                {allergy}
                <button 
                  type="button" 
                  onClick={() => removeFromList('allergies', index)}
                  className="remove-button"
                >
                  ×
                </button>
              </li>
            ))}
          </ul>
        </div>
      </div>
      
      <div className="form-section">
        <h3>Special Instructions</h3>
        <div className="list-with-input">
          <input
            type="text"
            value={newInstruction}
            onChange={(e) => setNewInstruction(e.target.value)}
            placeholder="E.g., Friday is pizza night"
          />
          <button 
            type="button" 
            onClick={() => addToList('specialInstructions', newInstruction, setNewInstruction)}
          >
            Add
          </button>
        </div>
        <ul className="tag-list">
          {localConfig.specialInstructions.map((instruction, index) => (
            <li key={`instruction-${index}`} className="tag">
              {instruction}
              <button 
                type="button" 
                onClick={() => removeFromList('specialInstructions', index)}
                className="remove-button"
              >
                ×
              </button>
            </li>
          ))}
        </ul>
      </div>
      
      <div className="form-section">
        <h3>Cooking Equipment</h3>
        <div className="list-with-input">
          <input
            type="text"
            value={newEquipment}
            onChange={(e) => setNewEquipment(e.target.value)}
            placeholder="E.g., oven, microwave"
          />
          <button 
            type="button" 
            onClick={() => addToList('cookingEquipment', newEquipment, setNewEquipment)}
          >
            Add
          </button>
        </div>
        <ul className="tag-list">
          {localConfig.cookingEquipment.map((equipment, index) => (
            <li key={`equipment-${index}`} className="tag">
              {equipment}
              <button 
                type="button" 
                onClick={() => removeFromList('cookingEquipment', index)}
                className="remove-button"
              >
                ×
              </button>
            </li>
          ))}
        </ul>
      </div>
      
      <div className="button-group">
        <button 
          type="button" 
          className="save-button"
          onClick={handleSaveConfig}
        >
          Save Configuration
        </button>
        <button 
          type="button" 
          className="generate-button"
          onClick={onGeneratePlan}
          disabled={isLoading}
        >
          {isLoading ? 'Generating...' : 'Generate Meal Plan'}
        </button>
      </div>
    </div>
  );
};

export default ConfigForm;
