import React, { useState } from 'react';
import './MealPlanDisplay.css';
import RawMealPlanViewer from './RawMealPlanViewer';
import MealPlanFeedback from './MealPlanFeedback';

const MealPlanDisplay = ({ plan }) => {
  const [activeView, setActiveView] = useState('summary');
  const [rawPlanText, setRawPlanText] = useState(plan.rawAIResponse || null);
  const [feedback, setFeedback] = useState([]);
  
  const handleFeedbackSubmit = (newFeedback) => {
    setFeedback([...feedback, newFeedback]);
    console.log('Feedback submitted:', newFeedback);
    // In a real app, this would trigger a regeneration of the meal plan
  };
  
  // This is a placeholder. In a real application, this would use actual data from the plan
  const formatDate = (date) => {
    return new Date(date).toLocaleDateString('en-US', {
      weekday: 'short',
      month: 'short',
      day: 'numeric'
    });
  };
  
  
  const renderSummaryView = () => {
    return (
      <div className="summary-view">
        <h3>Meal Plan Summary</h3>
        <table className="summary-table">
          <thead>
            <tr>
              <th>Date</th>
              <th>Dish</th>
              <th>Total Time</th>
              <th>Calories</th>
            </tr>
          </thead>
          <tbody>
            {plan.meals && plan.meals.map(meal => (
              <tr key={meal.id}>
                <td>{formatDate(new Date(meal.date))}</td>
                <td>{meal.name}</td>
                <td>{meal.totalTime}</td>
                <td>{meal.calories} cal</td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    );
  };
  
  const renderGroceryList = () => {
    return (
      <div className="grocery-list-view">
        <h3>Grocery List</h3>
        
        <div className="grocery-list-filters">
          <label>
            <input type="checkbox" defaultChecked={true} />
            Show Perishable Items
          </label>
          <label>
            <input type="checkbox" defaultChecked={true} />
            Show Non-Perishable Items
          </label>
        </div>
        
        <table className="grocery-table">
          <thead>
            <tr>
              <th>Ingredient</th>
            <th>Amount</th>
            <th>Perishable</th>
            </tr>
          </thead>
          <tbody>
            {plan.groceryLists && plan.groceryLists.length > 0 && plan.groceryLists[0].items.map((item, index) => (
              <tr key={index}>
                <td>{item.name}</td>
                <td>{item.amount}</td>
                <td>{item.perishable ? 'Yes' : 'No'}</td>
              </tr>
            ))}
          </tbody>
        </table>
      </div>
    );
  };
  
  const renderRecipesView = () => {
    return (
      <div className="recipes-view">
        <h3>Detailed Recipes</h3>
        
        {plan.parsedAIResponse && plan.parsedAIResponse.parsedData && plan.parsedAIResponse.parsedData.detailedRecipes}
      </div>
    );
  };
  
  const renderCalendarView = () => {
    return (
      <div className="calendar-view">
        <h3>Calendar View</h3>
        {plan.parsedAIResponse && plan.parsedAIResponse.parsedData && plan.parsedAIResponse.parsedData.calendarView}
      </div>
    );
  };
  
  return (
    <div className="meal-plan-display">
      <h2>Your Generated Meal Plan</h2>
      
      <div className="view-selector">
        <button
          className={activeView === 'summary' ? 'active' : ''}
          onClick={() => setActiveView('summary')}
        >
          Summary
        </button>
        <button
          className={activeView === 'grocery' ? 'active' : ''}
          onClick={() => setActiveView('grocery')}
        >
          Grocery List
        </button>
        <button
          className={activeView === 'recipes' ? 'active' : ''}
          onClick={() => setActiveView('recipes')}
        >
          Full Recipes
        </button>
        <button
          className={activeView === 'calendar' ? 'active' : ''}
          onClick={() => setActiveView('calendar')}
        >
          Calendar View
        </button>
        <button
          className={activeView === 'raw' ? 'active' : ''}
          onClick={() => setActiveView('raw')}
        >
          Raw Text
        </button>
      </div>
      
      <div className="view-content">
        {activeView === 'summary' && renderSummaryView()}
        {activeView === 'grocery' && renderGroceryList()}
        {activeView === 'recipes' && renderRecipesView()}
        {activeView === 'calendar' && renderCalendarView()}
        {activeView === 'raw' && <RawMealPlanViewer rawPlan={plan.rawAIResponse.text} />}
        
      </div>
      
      <MealPlanFeedback onSubmitFeedback={handleFeedbackSubmit} />
    </div>
  );
};

export default MealPlanDisplay;
