import React, { useState, useEffect } from 'react';
import './SavedConfigs.css';

const SavedConfigs = ({ onLoadConfig }) => {
  const [savedConfigs, setSavedConfigs] = useState([]);
  const [newConfigName, setNewConfigName] = useState('');
  const [showSaveDialog, setShowSaveDialog] = useState(false);
  
  // Load saved configurations from localStorage on component mount
  useEffect(() => {
    const configs = localStorage.getItem('mealPlannerConfigs');
    if (configs) {
      setSavedConfigs(JSON.parse(configs));
    }
  }, []);
  
  const handleSaveConfig = (name) => {
    // Get current configuration
    const currentConfig = localStorage.getItem('currentMealPlanConfig');
    if (!currentConfig) return;
    
    const config = JSON.parse(currentConfig);
    config.name = name;
    config.savedAt = new Date().toISOString();
    
    // Add to saved configs
    const updatedConfigs = [...savedConfigs, config];
    setSavedConfigs(updatedConfigs);
    
    // Save to localStorage
    localStorage.setItem('mealPlannerConfigs', JSON.stringify(updatedConfigs));
    
    // Reset dialog
    setNewConfigName('');
    setShowSaveDialog(false);
  };
  
  const handleDeleteConfig = (index) => {
    const updatedConfigs = savedConfigs.filter((_, i) => i !== index);
    setSavedConfigs(updatedConfigs);
    localStorage.setItem('mealPlannerConfigs', JSON.stringify(updatedConfigs));
  };
  
  const handleLoadConfig = (config) => {
    if (onLoadConfig) {
      // Parse date string back to Date object
      const loadedConfig = {...config};
      loadedConfig.startDate = new Date(config.startDate);
      onLoadConfig(loadedConfig);
    }
  };
  
  return (
    <div className="saved-configs">
      <div className="saved-configs-header">
        <h3>Saved Configurations</h3>
        <button 
          type="button" 
          className="save-new-button"
          onClick={() => setShowSaveDialog(true)}
        >
          Save Current Config
        </button>
      </div>
      
      {showSaveDialog && (
        <div className="save-dialog">
          <input
            type="text"
            value={newConfigName}
            onChange={(e) => setNewConfigName(e.target.value)}
            placeholder="Enter a name for this configuration"
          />
          <div className="dialog-buttons">
            <button 
              type="button"
              onClick={() => handleSaveConfig(newConfigName)}
              disabled={!newConfigName.trim()}
            >
              Save
            </button>
            <button 
              type="button"
              onClick={() => setShowSaveDialog(false)}
            >
              Cancel
            </button>
          </div>
        </div>
      )}
      
      {savedConfigs.length === 0 ? (
        <p className="no-configs">No saved configurations yet</p>
      ) : (
        <ul className="configs-list">
          {savedConfigs.map((config, index) => (
            <li key={index} className="config-item">
              <div className="config-info">
                <h4>{config.name}</h4>
                <p>
                  {new Date(config.savedAt).toLocaleDateString()} | 
                  {config.portions} portions | 
                  {config.likedFlavors.length} liked flavors
                </p>
              </div>
              <div className="config-actions">
                <button 
                  type="button"
                  className="load-button"
                  onClick={() => handleLoadConfig(config)}
                >
                  Load
                </button>
                <button 
                  type="button"
                  className="delete-button"
                  onClick={() => handleDeleteConfig(index)}
                >
                  Delete
                </button>
              </div>
            </li>
          ))}
        </ul>
      )}
    </div>
  );
};

export default SavedConfigs;
