// Service for communicating with AI models to generate meal plans
// Uses Google's Gemini API for generating the meal plans

import GeminiService from './GeminiService';

// Initialize Gemini service with API key
// In production, this should be stored in environment variables
const GEMINI_API_KEY = 'AIzaSyAIxqZ9V0Ozj1u5-WCGdSu6_MNSKyCuRJU';
const geminiService = new GeminiService(GEMINI_API_KEY);

const AIService = {
  // Generate a prompt for the AI based on user configuration
  buildPrompt: (config) => {
    const startDateFormatted = config.startDate.toLocaleDateString('en-US', {
      weekday: 'long',
      month: 'numeric',
      day: 'numeric',
      year: 'numeric'
    });
    
    // Build the prompt based on user configuration
    let prompt = `Generate a meal plan for ${config.numberOfIntervals} ${config.shoppingIntervalUnit}, generating ${config.numberOfIntervals} ${config.shoppingIntervalUnit} at a time.
Please return the response as a JSON object with the following structure, wrapped in a markdown code block like \`\`\`json ... \`\`\`:
{
  "summaryTable": "Markdown table string for the summary table",
  "groceryList": "Markdown list/table string for the grocery list",
  "detailedRecipes": "Markdown text for all detailed recipes",
  "calendarView": "Markdown table string for the calendar view"
}
Ensure the content within the \`\`\`json\`\`\` block is a valid JSON string.`;

    // Add special instructions
    if (config.specialInstructions && config.specialInstructions.length > 0) {
      config.specialInstructions.forEach(instruction => {
        prompt += ` ${instruction}.`;
      });
    }

    // Add cooking equipment
    if (config.cookingEquipment && config.cookingEquipment.length > 0) {
      prompt += ` We have ${config.cookingEquipment.join(', ')}.`;
    }

    // Add flavor preferences
    if (config.likedFlavors && config.likedFlavors.length > 0) {
      prompt += ` We like ${config.likedFlavors.join(', ')} dishes.`;
    }

    if (config.dislikedFlavors && config.dislikedFlavors.length > 0) {
      prompt += ` We don't like ${config.dislikedFlavors.join(', ')}.`;
    }

    // Add allergies
    if (config.allergies && config.allergies.length > 0) {
      prompt += ` We have allergies to ${config.allergies.join(', ')}.`;
    }

    // Add standard instructions for meal plan format
    prompt += `
We need to build a grocery list that we pickup on the first day of each interval and lasts for the duration of the interval. Account for perishable ingredients like fresh mushrooms and bread.
Call out when meats should be pulled out of the freezer for future meals, and when prep work should be done such as marinades or vegetables that can be prepped ahead of time.
Include recipes for each day for ${config.portions} servings. Document meat temps where relevant. List ingredients by both volume and weight measurements.
Do this for the next ${config.numberOfIntervals} ${config.shoppingIntervalUnit}, with a grocery list for the start of each interval and different plans for each interval. Include serving and side suggestions and approximate calorie count per dish serving. Include information with each dish how to store leftovers and how long they will last in the fridge. Where possible suggest bulk quantities that can be used over the course of the month.
Start with a summary table of dishes that outlines dish name, total time required to make, calories, and the date it should be done on. The start date is ${startDateFormatted}.
Next supply a table of the full ingredients list for all dishes. Show name and quantity and a flag for is perishable for items with short lifespans.
Next list out each day in order with the full recipe. Each recipe should start with the ingredients list, then cooking/prep instructions. Include measurements in the recipe instructions as they are listed. For example "Add 1/3 cup whole milk".
Lastly, summarize all dishes by name on a table laid out as a calendar. Each cell should have the date and the dish name only.`;

    return prompt;
  },

  // Call Gemini API to generate meal plan based on prompt
  generateWithAI: async (prompt) => {
    try {
      console.log('Sending prompt to Gemini API:', prompt);

      // Setting a lower temperature for more deterministic results since this is a structured task
      const options = {
        temperature: 0.4,
        maxOutputTokens: 8192, // Maximum allowed for detailed meal plans
        topK: 40,
        topP: 0.95,
      };

      // Call Gemini API with the prompt
      const response = await geminiService.generateText(prompt, options);

      console.log('Received response from Gemini API');

      return {
        success: true,
        text: response.text,
        prompt,
        rawResponse: response
      };
    } catch (error) {
      console.error('Error generating meal plan with Gemini:', error);
      throw error;
    }
  },

  // Parse AI response into structured meal plan data
  // This extracts the relevant sections from AI response
  parseAIResponse: (aiResponse) => {
    if (!aiResponse || !aiResponse.text) {
      return {
        success: false,
        error: 'No AI response to parse'
      };
    }

    const text = aiResponse.text;
    let parsedJson;
    let jsonString = text; // Assume the whole text is JSON initially

    // Attempt to extract JSON from a markdown code block (```json ... ```)
    const jsonCodeBlockMatch = text.match(/```json\s*([\s\S]*?)\s*```/);

    if (jsonCodeBlockMatch && jsonCodeBlockMatch[1]) {
      console.log('Found JSON code block, attempting to parse content within.');
      jsonString = jsonCodeBlockMatch[1]; // Use content from the code block
    } else {
      console.warn('No JSON code block found, attempting to parse the entire response text as JSON.');
    }

    try {
      // Attempt to parse the extracted string (or original text if no code block) as JSON
      parsedJson = JSON.parse(jsonString);

      // Extract data from the parsed JSON object
      const summaryTable = parsedJson.summaryTable || '';
      const groceryList = parsedJson.groceryList || '';
      const detailedRecipes = parsedJson.detailedRecipes || '';
      const calendarView = parsedJson.calendarView || '';

      return {
        success: true,
        parsedData: {
          summaryTable,
          groceryList,
          detailedRecipes,
          calendarView,
          fullText: text // Keep full text for debugging/raw view
        }
      };
    } catch (error) {
      console.error('Error parsing AI response as JSON:', error);
      // If JSON parsing fails, fall back to the old regex parsing logic
      // This provides some robustness in case the AI doesn't return perfect JSON
      try {
        console.warn('JSON parsing failed, attempting regex parsing fallback.');
        // Extract summary table
        const summaryTableMatch = text.match(/^#+\s*Summary\s*(Table)?([\s\S]*?)(?=^#+\s*|\n\n\n|$)/im);
        const summaryTable = summaryTableMatch ? summaryTableMatch[1].trim() : '';

        // Extract grocery list
        const groceryListMatch = text.match(/^#+\s*Grocery\s*List?([\s\S]*?)(?=^#+\s*|\n\n\n|$)/im);
        const groceryList = groceryListMatch ? groceryListMatch[1].trim() : '';

        // Extract detailed recipes
        const detailedRecipesMatch = text.match(/^#+\s*Detailed?\s*Recipes([\s\S]*?)(?=^#+\s*|\n\n\n|$)/im);
        const detailedRecipes = detailedRecipesMatch ? detailedRecipesMatch[1].trim() : '';

        // Extract calendar view
        const calendarViewMatch = text.match(/^#+\s*Calendar\s*(View)?([\s\S]*?)(?=^#+\s*|\n\n\n|$)/im);
        const calendarView = calendarViewMatch ? calendarViewMatch[1].trim() : '';

        return {
          success: true,
          parsedData: {
            summaryTable,
            groceryList,
            detailedRecipes,
            calendarView,
            fullText: text
          }
        };
      } catch (regexError) {
        console.error('Regex parsing fallback also failed:', regexError);
        return {
          success: false,
          error: `Failed to parse AI response as JSON or using regex: ${error.message}`,
          fullText: text
        };
      }
    }
  }
};

export default AIService;
