// Service for interacting with Google's Gemini AI API
// This service handles communication with the Gemini Flash 2.5 Pro model

class GeminiService {
  constructor(apiKey) {
    this.apiKey = apiKey;
    this.baseUrl = 'https://generativelanguage.googleapis.com/v1beta/models';
    this.model = 'gemini-2.5-flash-preview-04-17'; // Updated model name
  }

  // Generate text from a prompt
  async generateText(prompt, options = {}) {
    const defaultOptions = {
      temperature: 0.7,
      maxOutputTokens: 8192,
      topK: 40,
      topP: 0.95,
    };

    const requestOptions = { ...defaultOptions, ...options };
    
    try {
      const url = `${this.baseUrl}/${this.model}:generateContent?key=${this.apiKey}`;
      
      const requestBody = {
        contents: [
          {
            parts: [
              {
                text: prompt
              }
            ]
          }
        ],
        generationConfig: {
          temperature: requestOptions.temperature,
          maxOutputTokens: requestOptions.maxOutputTokens,
          topK: requestOptions.topK,
          topP: requestOptions.topP
        }
      };
      
      console.log('Sending request to Gemini API...');
      
      const response = await fetch(url, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json'
        },
        body: JSON.stringify(requestBody)
      });
      
      if (!response.ok) {
        const errorData = await response.json();
        throw new Error(`Gemini API error: ${errorData.error.message || response.statusText}`);
      }
      
      const data = await response.json();
      
      if (!data.candidates || data.candidates.length === 0) {
        throw new Error('No response generated from Gemini');
      }
      
      // Extract the text from the response
      const generatedText = data.candidates[0].content.parts[0].text;
      
      return {
        text: generatedText,
        usage: data.usageMetadata,
        rawResponse: data
      };
    } catch (error) {
      console.error('Error generating text with Gemini:', error);
      throw error;
    }
  }
}

export default GeminiService;
